#
# spec file for package libzypp-plugin-appdata
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libzypp-plugin-appdata
Version:        1.0.1
Release:        13.2
Summary:        Extend libzypp to handle AppStream metadata
License:        MIT
Group:          System/Libraries
Url:            https://wiki.gnome.org/Design/Apps/Software
Source0:        openSUSE-appstream-1.0.tar.xz
Source2:        InstallAppdata.sh
BuildArch:      noarch
# appstream-glib >= 0.3.6 is the first to correctly to appstream-util uninstall in /var/cache
Requires:       appstream-glib >= 0.3.6
# appdata hook was introduced in libzypp 14.29.4
Requires:       libzypp >= 14.29.4
# appstreamcli is provided by the AppStream package
Requires:       AppStream
# The script uses awk to find the right filename for the appdata.xml.gz file
Requires:       awk

%description
This plugin extends libzypp to install AppStream metadata, as extracted from the
repository metadata, onto the file system in order to be picked up by
software centers.

At this moment, gnome-software is the only known implementation making use of it.

%package -n openSUSE-appdata-extra
Summary:        Additional Appstream Metadata
Group:          System

%description -n openSUSE-appdata-extra
This package contains extra appstream metadata to be used by appstream-builder

%prep
%setup -q -n openSUSE-appstream-1.0

%build

%install
# install the additional appstream metadata
install -m 0755 -d %{buildroot}%{_datadir}/appdata-extra
cp appdata-extra/*/* %{buildroot}%{_datadir}/appdata-extra/

# Install AppData zypp plugin - temporarily disabled in favor of static AppStream metadata
install -Dm 0755 %{S:2} %{buildroot}%{_prefix}/lib/zypp/plugins/appdata/$(basename %{S:2})

%files
%defattr(-,root,root)
# zypp plugin triggering AppData update on repo refresh
%dir %{_prefix}/lib/zypp
%dir %{_prefix}/lib/zypp/plugins
%dir %{_prefix}/lib/zypp/plugins/appdata/
%{_prefix}/lib/zypp/plugins/appdata/InstallAppdata.sh

%files -n openSUSE-appdata-extra
%defattr(-,root,root)
%{_datadir}/appdata-extra/

%changelog
* Fri Jul 15 2016 dimstar@opensuse.org
- InstallAppdata.sh: do not stumble over the presence of the
  appdata-failed.xml.gz file: this is for debug purpose and does
  not contain valid applications (boo#989031).
- Add awk Requires, as the latest modification relies on awk to
  find the right filenames.
* Tue May  3 2016 dimstar@opensuse.org
- InstallAppdata.sh: prepare for YaST type repositories to receive
  appdata.xml.gz and appdata-icons.tar.gz with a hashed filename in
  order to allow mirrorbrain to distribute it.
* Fri Feb  5 2016 tittiatcoke@gmail.com
- Expand the InstallAppdata.sh so that it (re)builds the Xapian
  database for the available appdata. This Xapian database is
  required by the KDE tools (Muon/Discover) to show the
  installed software
  * Add Requires on AppStream package as that this provides the
    appstreamcli binary
* Fri May  8 2015 dimstar@opensuse.org
- Fix installation of rpm-md provided metadata (expanding globs
  inside quotes does not work).
* Thu Apr 23 2015 dimstar@opensuse.org
- No need to validate appdata.xml.gz in a yast2 repo: those are
  created by kiwi, which in turn spanws appstream-builder: we can
  trust that it creates valid enough metadata.
* Tue Apr  7 2015 dimstar@opensuse.org
- Move openSUSE-appstream-process to appstream-glib package, as
  updating one often means a change in the other anyway.
- Rename openSUSE-appstream-extra to openSUSE-appdata-extra, to
  better reflect what content to expect in this package (after the
  github reorganisation).
* Thu Apr  2 2015 dimstar@opensuse.org
- InstallAppdata.sh: pass --nonet to appstream-util when
  validating appstream.xml.gz.
* Tue Mar 31 2015 dimstar@opensuse.org
- InstallAppdata.sh: only install AppStream metadata, that
  validates.
* Fri Mar 20 2015 dimstar@opensuse.org
- Re-enable the actual libzypp plugin in place of shipping a static
  version of appstream metadata (last updated for 13.2). We can do
  this, as Tumbleweed now produces valid metadata. 3rd party repos
  are not yet able to produce valid metadata it seems.
* Tue Mar 17 2015 dimstar@opensuse.org
- Pass --include-failed to appstream-builder (requires apb 0.3.5).
* Fri Mar 13 2015 dimstar@opensuse.org
- Require openSUSE-appstream-extra by openSUSE-appstream-process:
  Having the extra appstream metadata available will allow the
  builder to get better results.
* Fri Jan 23 2015 opensuse-packaging@opensuse.org
- Preparations on the way to get AppStream metadata produced in a
  more conform way.
- Add new subpackages:
  + openSUSE-appstream-extras:
  - Contains additional appstream metadata to assist upstreams
    not yet shipping their own .appdata.xml file.
  + openSUSE-appstream-process:
  - The processor is an attempt to be used by kiwi to produce
    valid appstream metadata.
* Wed Jan 21 2015 dimstar@opensuse.org
- Update InstallAppdata.sh: the yast2 metadata structure got a
  slight change with the switch to appstream-builder.
* Wed Nov  5 2014 dimstar@opensuse.org
- Update License to MIT, which matches the header in
  InstallAppdata.sh.
* Wed Oct 29 2014 dimstar@opensuse.org
- Bump version of libzypp-plugin-appdata to 1.0.1:
  + Disable the automatic metadata update mechanism, openSUSE 13.2
    metadata quality is not ready for this.
  + Inject offline generated metadata into the system, so that
    gnome-software has usable metadata.
* Wed Oct 29 2014 dimstar@opensuse.org
- Split out of gnome-software, to be able to easier maintain
  updates.
